/**
 * Marlin 3D Printer Firmware
 * Copyright (C) 2016 MarlinFirmware [https://github.com/MarlinFirmware/Marlin]
 *
 * Based on Sprinter and grbl.
 * Copyright (C) 2011 Camiel Gubbels / Erik van der Zalm
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/**
 * IMPORTANT NOTE:
 * Rambo users should be sure to compile Marlin using either the RAMBo
 * board type if using the Arduino IDE - available via the link below - or
 * the 'rambo' environment if using platformio, by specifying '-e rambo' on
 * the command line or by changing the value of the 'env_default' variable to
 * 'rambo' in the supplied platformio.ini.
 *
 * If you don't compile using the proper board type, the RAMBo's extended
 * pins will likely be unavailable and accessories/addons may not work.
 *
 * Instructions for installing the Arduino RAMBo board type for the
 * Arduino IDE are available at:
 * http://reprap.org/wiki/Rambo_firmware
 */

/**
 * Rambo pin assignments
 */

#ifndef __AVR_ATmega2560__
  #error "Oops!  Make sure you have 'Arduino Mega 2560' selected from the 'Tools -> Boards' menu."
#endif

#define BOARD_NAME "Einsy Rambo"

//
// Make sure the following is enabled in Configuration_adv.h
//

//
// TMC2130 Configuration_adv defaults for EinsyRambo
//
//#ifndef HAVE_TMC2130
//  #error Must enable TMC2130 support in Configuration_adv.h for EinsyRambo
//#endif

//#define X_IS_TMC2130
//#define Y_IS_TMC2130
//#define Z_IS_TMC2130
//#define E0_IS_TMC2130

//
// Servos
//
#define SERVO0_PIN         10 // Using the Probe (Z_MIN) header for the Orange BLTouch Cable
			      // The red / Brown cable (5v Positive) should be connected to the 5v connector below the endstop connectors
 			      // 

//
// Z Probe (when not Z_MIN_PIN)
//
#ifndef Z_MIN_PROBE_PIN
  #define Z_MIN_PROBE_PIN  30
#endif

//
// Limit Switches
//
#define X_MIN_PIN          64 // 2130 X Diag Pin
#define X_MAX_PIN          64
#define Y_MIN_PIN          69 // 2130 Y Diag Pin
#define Y_MAX_PIN          69
#define Z_MIN_PIN          11 // Using the Y_MIN pin header for the Black / White BLTouch Cable
#define Z_MAX_PIN          -1

//
// Steppers
//
#define X_STEP_PIN         37
#define X_DIR_PIN          49
#define X_ENABLE_PIN       29
#define X_CS_PIN	   41

#define Y_STEP_PIN         36
#define Y_DIR_PIN          48
#define Y_ENABLE_PIN       28
#define Y_CS_PIN	   39

#define Z_STEP_PIN         35
#define Z_DIR_PIN          47
#define Z_ENABLE_PIN       27
#define Z_CS_PIN	   67

#define E0_STEP_PIN        34
#define E0_DIR_PIN         43
#define E0_ENABLE_PIN      26
#define E0_CS_PIN	   66

#define E1_STEP_PIN        -1
#define E1_DIR_PIN         -1
#define E1_ENABLE_PIN      -1

// Microstepping pins - Mapping not from fastio.h (?)
#define X_MS1_PIN          -1
#define X_MS2_PIN          -1
#define Y_MS1_PIN          -1
#define Y_MS2_PIN          -1
#define Z_MS1_PIN          -1
#define Z_MS2_PIN          -1
#define E0_MS1_PIN         -1
#define E0_MS2_PIN         -1
#define E1_MS1_PIN         -1
#define E1_MS2_PIN         -1

#define MOTOR_CURRENT_PWM_XY_PIN 46
#define MOTOR_CURRENT_PWM_Z_PIN  45
#define MOTOR_CURRENT_PWM_E_PIN  44
// Motor current PWM conversion, PWM value = MotorCurrentSetting * 255 / range
#ifndef MOTOR_CURRENT_PWM_RANGE
  #define MOTOR_CURRENT_PWM_RANGE 2000
#endif
#define DEFAULT_PWM_MOTOR_CURRENT  {1300, 1300, 1250}


//#define DIGIPOTSS_PIN      38
//#define DIGIPOT_CHANNELS {4,5,3,0,1} // X Y Z E0 E1 digipot channels to stepper driver mapping

//
// Temperature Sensors
//
#define TEMP_0_PIN          0   // Analog Input
#define TEMP_1_PIN          1   // Analog Input
#define TEMP_BED_PIN        2   // Analog Input

//
// Heaters / Fans
//
#define HEATER_0_PIN        3
#define HEATER_1_PIN        -1
#define HEATER_2_PIN        -1
#define HEATER_BED_PIN      4

#define FAN_PIN             8
#define FAN1_PIN            6
//#define FAN2_PIN            2

//
// Misc. Functions
//
#define SDSS               77
#define LED_PIN            13
//#define PS_ON_PIN           4
#define CASE_LIGHT_PIN      9

//#ifndef FILWIDTH_PIN
//  #define FILWIDTH_PIN      3   // Analog Input
//#endif

//
// M3/M4/M5 - Spindle/Laser Control
//
#define SPINDLE_LASER_PWM_PIN     9  // MUST BE HARDWARE PWM
#define SPINDLE_LASER_ENABLE_PIN 18  // Pin should have a pullup!
#define SPINDLE_DIR_PIN          19

//
// Průša i3 MK2 Multiplexer Support
//
#define E_MUX0_PIN         17
#define E_MUX1_PIN         16
#define E_MUX2_PIN         78 // 84 in MK2 Firmware

//
// LCD / Controller
//
#if ENABLED(ULTRA_LCD)

  #define KILL_PIN 32

  #if ENABLED(NEWPANEL)

    #define BEEPER_PIN 84 // On AUX-4

    #define LCD_PINS_RS     82
    #define LCD_PINS_ENABLE 61
    #define LCD_PINS_D4     59
    #define LCD_PINS_D5     70
    #define LCD_PINS_D6     85
    #define LCD_PINS_D7     71

    #define BTN_EN1 14
    #define BTN_EN2 72
    #define BTN_ENC  9

    #define SD_DETECT_PIN 15 // Pin 72 if using easy adapter board

  #endif // !NEWPANEL

#endif // ULTRA_LCD
